==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/ru.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Поделились с вами",
    "Shared with others" : "Доступные для других",
    "Shared by link" : "Доступные по ссылке",
    "Nothing shared with you yet" : "С вами пока ничем не поделились",
    "Files and folders others share with you will show up here" : "Здесь появятся файлы и каталоги, которыми с вами поделятся",
    "Nothing shared yet" : "Пока ничего не опубликовано",
    "Files and folders you share will show up here" : "Здесь появятся файлы и каталоги, которыми вы поделитесь",
    "No shared links" : "Нет общих ссылок",
    "Files and folders you share by link will show up here" : "Здесь появятся файлы и каталоги, ссылкой на которые вы поделитесь",
    "You can upload into this folder" : "Вы можете загружать в этот каталог",
    "No compatible server found at {remote}" : "Не найден совместимый сервер на {remote}",
    "Invalid server URL" : "Неверный URL сервера",
    "Failed to add the public link to your Nextcloud" : "Не получилось добавить публичную ссылку на ваш Nextcloud",
    "Share" : "Поделиться",
    "No expiration date set" : "Дата истечения не установлена",
    "Shared by" : "Поделился",
    "Sharing" : "Общий доступ",
    "File shares" : "Файловые ресурсы общего доступа",
    "Downloaded via public link" : "Скачано по открытой ссылке",
    "Downloaded by %1$s" : "Скачано %1$s",
    "Downloaded by {email}" : "Скачано {email}",
    "%1$s downloaded via public link" : "%1$s скачано по публичной ссылке",
    "{file} downloaded via public link" : "{file} скачан по публичной ссылке",
    "%1$s downloaded %2$s" : "%1$s скачан %2$s",
    "{email} downloaded {file}" : "{email} скачал {file}",
    "Shared with group %1$s" : "Поделился с группой %1$s",
    "Shared with group {group}" : "Поделился с группой {group}",
    "Removed share for group %1$s" : "Закрыт общий доступ для группы %1$s",
    "Removed share for group {group}" : "Закрыт общий доступ для группы {group}",
    "%2$s shared with group %1$s" : "%2$s поделился с группой %1$s",
    "{actor} shared with group {group}" : "{actor} поделился с группой {group}",
    "%2$s removed share for group %1$s" : "%2$s удалил общий доступ для группы %1$s",
    "{actor} removed share for group {group}" : "{actor} закрыл общий доступ для группы {group}",
    "You shared %1$s with group %2$s" : "Вы поделились %1$s с группой %2$s",
    "You shared {file} with group {group}" : "Вы поделились {file} с группой {group}",
    "You removed group %2$s from %1$s" : "Вы удалили группу %2$s из %1$s",
    "You removed group {group} from {file}" : "Вы удалили группу {group} из {file}",
    "%3$s shared %1$s with group %2$s" : "%3$s поделился %1$s с группой %2$s",
    "{actor} shared {file} with group {group}" : "{actor} поделился {file} с группой {group}",
    "%3$s removed group %2$s from %1$s" : "%3$s удалил группу %2$s из %1$s",
    "{actor} removed group {group} from {file}" : "{actor} удалил группу {group} из {file}",
    "Shared as public link" : "Поделился публичной ссылкой",
    "Removed public link" : "Удалена публичная ссылка",
    "%1$s shared as public link" : "%1$s поделился публичной ссылкой",
    "{actor} shared as public link" : "{actor} поделился публичной ссылкой",
    "%1$s removed public link" : "%1$s удалил публичную сслыку",
    "{actor} removed public link" : "{actor} удалил публичную ссылку",
    "You shared %1$s as public link" : "Вы поделись %1$s в виде публичной ссылки",
    "You shared {file} as public link" : "Вы поделись  {file} в виде публичной ссылки",
    "You removed public link for %1$s" : "Вы удалили публичную ссылку к %1$s",
    "You removed public link for {file}" : "Вы удалили публичную ссылку к {file}",
    "%2$s shared %1$s as public link" : "%2$s поделился %1$s в виде публичной ссылки",
    "{actor} shared {file} as public link" : "{actor} поделился {file} в виде публичной ссылки",
    "%2$s removed public link for %1$s" : "%2$s удалил публичную ссылку к %1$s",
    "{actor} removed public link for {file}" : "{actor} удалил публичную ссылку к {file}",
    "%1$s accepted the remote share" : "%1$s принял удаленный общий ресурс",
    "{user} accepted the remote share" : "{user} принял удаленный общий ресурс",
    "%1$s declined the remote share" : "%1$s отклонил удаленный общий ресурс",
    "{user} declined the remote share" : "{user} отклонил удаленный общий ресурс",
    "You received a new remote share %1$s from %2$s" : "Вы получили новый удаленный общий ресурс %1$s от %2$s",
    "You received a new remote share {file} from {user}" : "Вы получили новый удаленный общий ресурс {file} от {user}",
    "%2$s accepted the remote share of %1$s" : "%2$s принял удаленный общий ресурс %1$s",
    "{user} accepted the remote share of {file}" : "{user} принял удаленный общий ресурс {file}",
    "%2$s declined the remote share of %1$s" : "%2$s отклонил удаленный общий ресурс %1$s",
    "{user} declined the remote share of {file}" : "{user} отклонил удаленный общий ресурс {file}",
    "%2$s unshared %1$s from you" : "%2$s закрыл для вас доступ к %1$s ",
    "{user} unshared {file} from you" : "{user} закрыл для вас доступ к {file}",
    "Shared with %1$s" : "Поделился с %1$s",
    "Shared with {user}" : "Поделился с {user}",
    "Removed share for %1$s" : "Закрыт общий доступ для %1$s",
    "Removed share for {user}" : "Закрыт общий доступ для {user}",
    "%2$s shared with %1$s" : "%2$s поделился с %1$s",
    "{actor} shared with {user}" : "{actor} поделился с {user}",
    "%2$s removed share for %1$s" : "%2$s закрыл общий доступ к %1$s",
    "{actor} removed share for {user}" : "{actor} закрыл общий доступ для {user}",
    "Shared by %1$s" : "Поделился через %1$s",
    "Shared by {actor}" : "Поделился через {actor}",
    "%1$s removed share" : "%1$s закрыл общий доступ",
    "{actor} removed share" : "{actor} закрыл общий доступ",
    "You shared %1$s with %2$s" : "Вы поделились %1$s с %2$s",
    "You shared {file} with {user}" : "Вы поделились {file} с {user}",
    "You removed %2$s from %1$s" : "Вы удалили %2$s из %1$s",
    "You removed {user} from {file}" : "Вы удалили {user} из {file}",
    "%3$s shared %1$s with %2$s" : "%3$s поделился %1$s с %2$s",
    "{actor} removed {user} from {file}" : "{actor} удалил {user} из {file}",
    "%3$s removed %2$s from %1$s" : "%3$s удалил %2$s из %1$s",
    "%2$s shared %1$s with you" : "%2$s поделился с вами %1$s",
    "{actor} shared {file} with you" : "{actor} поделился {file} с вами",
    "%2$s removed you from %1$s" : "%2$s удалил вас из %1$s",
    "{actor} removed you from {file}" : "{actor} удалил вас из {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Файл или папка, которыми поделились по электронной почте или публичной ссылке, были <strong>скачаны</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Файлом или каталогом поделились с <strong>удаленного сервера</strong>",
    "A file or folder has been <strong>shared</strong>" : "<strong>Опубликован</strong> файл или каталог",
    "Wrong share ID, share doesn't exist" : "Неверный идентификатор публикации, публикация не существует",
    "could not delete share" : "Не удалось удалить общий ресурс",
    "Could not delete share" : "Не удалось удалить публикацию",
    "Please specify a file or folder path" : "Пожалуйста, укажите путь к файлу или каталогу",
    "Wrong path, file/folder doesn't exist" : "Неверный путь, файл/каталог не существует",
    "Could not create share" : "Не удалось создать общий ресурс",
    "invalid permissions" : "Неверные права",
    "Please specify a valid user" : "Пожалуйста, укажите допустимого пользователя",
    "Group sharing is disabled by the administrator" : "Общий доступ для групп отключён администратором",
    "Please specify a valid group" : "Пожалуйста, укажите допустимую группу",
    "Public link sharing is disabled by the administrator" : "Публикация через общие ссылки отключена администратором",
    "Public upload disabled by the administrator" : "Загрузка в общедоступную публикацию запрещена администратором",
    "Public upload is only possible for publicly shared folders" : "Общедоступная загрузка возможна только в папки с общим доступом",
    "Invalid date, date format must be YYYY-MM-DD" : "Неверная дата, формат даты должен быть ГГГГ-ММ-ДД",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Не удалось поделиться %s, поскольку механизм удалённого обмена не разрешает публикации типа %s",
    "Unknown share type" : "Предоставление доступа неизвестного типа",
    "Not a directory" : "Это не каталог",
    "Could not lock path" : "Не удалось заблокировать путь",
    "Wrong or no update parameter given" : "Параметр для изменения неправилен или не задан",
    "Can't change permissions for public share links" : "Невозможно изменить права для публикации через ссылку",
    "Cannot increase permissions" : "Нельзя увеличить права",
    "%s is publicly shared" : "%s опубликован",
    "Share API is disabled" : "API общего доступа отключён",
    "This share is password-protected" : "Общий ресурс защищен паролем",
    "The password is wrong. Try again." : "Неверный пароль. Попробуйте еще раз.",
    "Password" : "Пароль",
    "No entries found in this folder" : "Нет элементов в этом каталоге",
    "Name" : "Имя",
    "Share time" : "Дата публикации",
    "Expiration date" : "Дата истечения",
    "Sorry, this link doesn’t seem to work anymore." : "Эта ссылка устарела и более не действительна.",
    "Reasons might be:" : "Причиной может быть:",
    "the item was removed" : "элемент был удалён",
    "the link expired" : "срок действия ссылки истёк",
    "sharing is disabled" : "общий доступ отключён",
    "For more info, please ask the person who sent this link." : "Для получения дополнительной информации, свяжитесь с тем, кто отправил вам эту ссылку.",
    "Add to your Nextcloud" : "Добавить к вашему Nextcloud",
    "Download" : "Скачать",
    "Download %s" : "Скачать %s",
    "Direct link" : "Прямая ссылка",
    "Upload files to %s" : "Загрузка файлов пользователю %s",
    "Select or drop files" : "Выбрать или сбросить файлы",
    "Uploading files…" : "Загрузка файлов...",
    "Uploaded files:" : "Загруженные файлы:",
    "A public shared file or folder was <strong>downloaded</strong>" : "<strong>Скачан</strong> общий файл или каталог",
    "You received a new remote share %2$s from %1$s" : "Вы получили новый удаленный общий ресурс %2$s от %1$s",
    "You received a new remote share from %s" : "%s поделился с вами удаленным общим ресурсом",
    "%1$s accepted remote share %2$s" : "%1$s принял удаленный общий ресурс %2$s",
    "%1$s declined remote share %2$s" : "%1$s отклонил удаленный общий ресурс %2$s",
    "%1$s unshared %2$s from you" : "%1$s закрыл для вас доступ к %2$s ",
    "Public shared folder %1$s was downloaded" : "Общий каталог %1$s был скачан",
    "Public shared file %1$s was downloaded" : "Общий файл %1$s, был скачан",
    "%2$s shared %1$s with %3$s" : "%2$s поделился %1$s с %3$s",
    "You removed the share of %2$s for %1$s" : "Вы удалили общий доступ к %2$s для %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s удалил общий доступ к %3$s для %1$s",
    "%2$s shared %1$s with group %3$s" : "%2$s поделился %1$s с группой %3$s",
    "You removed the share of group %2$s for %1$s" : "Вы удалили общий доступ к группе %2$s для %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s удалил общий доступ к группе %3$s для %1$s",
    "%2$s shared %1$s via link" : "%2$s поделился %1$s по ссылке",
    "You shared %1$s via link" : "Вы поделились %1$s с помощью ссылки",
    "You removed the public link for %1$s" : "Вы удалили публичную ссылку к %1$s",
    "%2$s removed the public link for %1$s" : "%2$s удалил публичную ссылку к %1$s",
    "Your public link for %1$s expired" : "Срок действия Вашей публичной ссылки к %1$s закончился",
    "The public link of %2$s for %1$s expired" : "Срок действия публичной ссылки к %2$s для %1$s закончился",
    "%2$s removed the share for %1$s" : "%2$s удалил общий доступ к %1$s",
    "Shared with %2$s" : "Поделился с %2$s",
    "Shared with %3$s by %2$s" : "Поделился %2$s с %3$s",
    "Removed share for %2$s" : "Удалён общий доступ к %2$s",
    "%2$s removed share for %3$s" : "%2$s удалил общий доступ к %3$s",
    "Shared with group %2$s" : "Поделился с группой %2$s",
    "Shared with group %3$s by %2$s" : "Поделился %2$s с группой %3$s",
    "Removed share of group %2$s" : "Удалён общий доступ к группе %2$s",
    "%2$s removed share of group %3$s" : "%2$s удалил общий доступ к группе %3$s",
    "Shared via link by %2$s" : "Поделился ссылкой %2$s",
    "Shared via public link" : "Поделился открытой ссылкой",
    "%2$s removed public link" : "%2$s удалил публичную ссылку",
    "Public link expired" : "Срок действия публичной ссылки закончился",
    "Public link of %2$s expired" : "Срок действия публичной ссылки к %2$s закончился",
    "Shared by %2$s" : "Поделился %2$s",
    "Shares" : "События обмена файлами"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/ru.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Поделились с вами",
    "Shared with others" : "Доступные для других",
    "Shared by link" : "Доступные по ссылке",
    "Nothing shared with you yet" : "С вами пока ничем не поделились",
    "Files and folders others share with you will show up here" : "Здесь появятся файлы и каталоги, которыми с вами поделятся",
    "Nothing shared yet" : "Пока ничего не опубликовано",
    "Files and folders you share will show up here" : "Здесь появятся файлы и каталоги, которыми вы поделитесь",
    "No shared links" : "Нет общих ссылок",
    "Files and folders you share by link will show up here" : "Здесь появятся файлы и каталоги, ссылкой на которые вы поделитесь",
    "You can upload into this folder" : "Вы можете загружать в этот каталог",
    "No compatible server found at {remote}" : "Не найден совместимый сервер на {remote}",
    "Invalid server URL" : "Неверный URL сервера",
    "Failed to add the public link to your Nextcloud" : "Не получилось добавить общедоступную ссылку в ваш Nextcloud",
    "Share" : "Поделиться",
    "No expiration date set" : "Дата истечения не установлена",
    "Shared by" : "Поделился",
    "Sharing" : "Общий доступ",
    "File shares" : "Файловые ресурсы общего доступа",
    "Downloaded via public link" : "Скачано по открытой ссылке",
    "Downloaded by {email}" : "Скачано {email}",
    "{file} downloaded via public link" : "{file} скачан по общедоступной ссылке",
    "{email} downloaded {file}" : "{email} скачал {file}",
    "Shared with group {group}" : "Поделился с группой {group}",
    "Removed share for group {group}" : "Закрыт общий доступ для группы {group}",
    "{actor} shared with group {group}" : "{actor} поделился с группой {group}",
    "{actor} removed share for group {group}" : "{actor} закрыл общий доступ для группы {group}",
    "You shared {file} with group {group}" : "Вы поделились {file} с группой {group}",
    "You removed group {group} from {file}" : "Вы удалили группу {group} из {file}",
    "{actor} shared {file} with group {group}" : "{actor} поделился {file} с группой {group}",
    "{actor} removed group {group} from {file}" : "{actor} удалил группу {group} из {file}",
    "Shared as public link" : "Поделился общедоступной ссылкой",
    "Removed public link" : "Удалена общедоступная ссылка",
    "Public link expired" : "Срок действия общедоступнной ссылки закончился",
    "{actor} shared as public link" : "{actor} поделился общедоступной ссылкой",
    "{actor} removed public link" : "{actor} удалил общедоступной ссылку",
    "Public link of {actor} expired" : "Истёе срок действия общедоступной ссылки пользователя {actor}",
    "You shared {file} as public link" : "Вы поделись  {file} в виде общедоступной ссылки",
    "You removed public link for {file}" : "Вы удалили общедоступную ссылку к {file}",
    "Public link expired for {file}" : "Истёк срок действия общедоступной ссылки для файла {file}",
    "{actor} shared {file} as public link" : "{actor} поделился {file} в виде общедоступной ссылки",
    "{actor} removed public link for {file}" : "{actor} удалил общедоступную ссылку к {file}",
    "Public link of {actor} for {file} expired" : "Истёк срок действия общедоступной ссылки пользователя {actor} на файл {file}",
    "{user} accepted the remote share" : "{user} принял удаленный общий ресурс",
    "{user} declined the remote share" : "{user} отклонил удаленный общий ресурс",
    "You received a new remote share {file} from {user}" : "Вы получили новый удаленный общий ресурс {file} от {user}",
    "{user} accepted the remote share of {file}" : "{user} принял удаленный общий ресурс {file}",
    "{user} declined the remote share of {file}" : "{user} отклонил удаленный общий ресурс {file}",
    "{user} unshared {file} from you" : "{user} закрыл для вас доступ к {file}",
    "Shared with {user}" : "Поделился с {user}",
    "Removed share for {user}" : "Закрыт общий доступ для {user}",
    "{actor} shared with {user}" : "{actor} поделился с {user}",
    "{actor} removed share for {user}" : "{actor} закрыл общий доступ для {user}",
    "Shared by {actor}" : "Поделился через {actor}",
    "{actor} removed share" : "{actor} закрыл общий доступ",
    "You shared {file} with {user}" : "Вы поделились {file} с {user}",
    "You removed {user} from {file}" : "Вы удалили {user} из {file}",
    "{actor} removed {user} from {file}" : "{actor} удалил {user} из {file}",
    "{actor} shared {file} with you" : "{actor} поделился {file} с вами",
    "{actor} removed you from {file}" : "{actor} удалил вас из {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Файл или папка, которыми поделились по электронной почте или общедоступной ссылке, были <strong>скачаны</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Файлом или каталогом поделились с <strong>удаленного сервера</strong>",
    "A file or folder has been <strong>shared</strong>" : "<strong>Опубликован</strong> файл или каталог",
    "Wrong share ID, share doesn't exist" : "Неверный идентификатор публикации, публикация не существует",
    "could not delete share" : "Не удалось удалить общий ресурс",
    "Could not delete share" : "Не удалось удалить публикацию",
    "Please specify a file or folder path" : "Пожалуйста, укажите путь к файлу или каталогу",
    "Wrong path, file/folder doesn't exist" : "Неверный путь, файл/каталог не существует",
    "Could not create share" : "Не удалось создать общий ресурс",
    "invalid permissions" : "Неверные права",
    "Please specify a valid user" : "Пожалуйста, укажите допустимого пользователя",
    "Group sharing is disabled by the administrator" : "Общий доступ для групп отключён администратором",
    "Please specify a valid group" : "Пожалуйста, укажите допустимую группу",
    "Public link sharing is disabled by the administrator" : "Публикация через общие ссылки отключена администратором",
    "Public upload disabled by the administrator" : "Загрузка в общедоступную публикацию запрещена администратором",
    "Public upload is only possible for publicly shared folders" : "Общедоступная загрузка возможна только в папки с общим доступом",
    "Invalid date, date format must be YYYY-MM-DD" : "Неверная дата, формат даты должен быть ГГГГ-ММ-ДД",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Не удалось поделиться %s, поскольку механизм удалённого обмена не разрешает публикации типа %s",
    "Unknown share type" : "Предоставление доступа неизвестного типа",
    "Not a directory" : "Это не каталог",
    "Could not lock path" : "Не удалось заблокировать путь",
    "Wrong or no update parameter given" : "Параметр для изменения неправилен или не задан",
    "Can't change permissions for public share links" : "Невозможно изменить права для публикации через ссылку",
    "Cannot increase permissions" : "Нельзя увеличить права",
    "%s is publicly shared" : "%s опубликован",
    "Share API is disabled" : "API общего доступа отключён",
    "This share is password-protected" : "Общий ресурс защищен паролем",
    "The password is wrong. Try again." : "Неверный пароль. Попробуйте еще раз.",
    "Password" : "Пароль",
    "No entries found in this folder" : "Нет элементов в этом каталоге",
    "Name" : "Имя",
    "Share time" : "Дата публикации",
    "Expiration date" : "Дата истечения",
    "Sorry, this link doesn’t seem to work anymore." : "Эта ссылка устарела и более не действительна.",
    "Reasons might be:" : "Причиной может быть:",
    "the item was removed" : "элемент был удалён",
    "the link expired" : "срок действия ссылки истёк",
    "sharing is disabled" : "общий доступ отключён",
    "For more info, please ask the person who sent this link." : "Для получения дополнительной информации, свяжитесь с тем, кто отправил вам эту ссылку.",
    "Add to your Nextcloud" : "Добавить к вашему Nextcloud",
    "Download" : "Скачать",
    "Download %s" : "Скачать %s",
    "Direct link" : "Прямая ссылка",
    "Upload files to %s" : "Загрузка файлов пользователю %s",
    "Select or drop files" : "Выбрать или сбросить файлы",
    "Uploading files…" : "Загрузка файлов...",
    "Uploaded files:" : "Загруженные файлы:",
    "A public shared file or folder was <strong>downloaded</strong>" : "<strong>Скачан</strong> общий файл или каталог",
    "You received a new remote share %2$s from %1$s" : "Вы получили новый удаленный общий ресурс %2$s от %1$s",
    "You received a new remote share from %s" : "%s поделился с вами удаленным общим ресурсом",
    "%1$s accepted remote share %2$s" : "%1$s принял удаленный общий ресурс %2$s",
    "%1$s declined remote share %2$s" : "%1$s отклонил удаленный общий ресурс %2$s",
    "%1$s unshared %2$s from you" : "%1$s закрыл для вас доступ к %2$s ",
    "Public shared folder %1$s was downloaded" : "Общий каталог %1$s был скачан",
    "Public shared file %1$s was downloaded" : "Общий файл %1$s, был скачан",
    "You shared %1$s with %2$s" : "Вы поделились %1$s с %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s поделился %1$s с %3$s",
    "You removed the share of %2$s for %1$s" : "Вы удалили общий доступ к %2$s для %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s удалил общий доступ к %3$s для %1$s",
    "You shared %1$s with group %2$s" : "Вы поделились %1$s с группой %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s поделился %1$s с группой %3$s",
    "You removed the share of group %2$s for %1$s" : "Вы удалили общий доступ к группе %2$s для %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s удалил общий доступ к группе %3$s для %1$s",
    "%2$s shared %1$s via link" : "%2$s поделился %1$s по ссылке",
    "You shared %1$s via link" : "Вы поделились %1$s с помощью ссылки",
    "You removed the public link for %1$s" : "Вы удалили общедоступную ссылку к %1$s",
    "%2$s removed the public link for %1$s" : "%2$s удалил общедоступную ссылку к %1$s",
    "Your public link for %1$s expired" : "Срок действия Вашей общедоступной ссылки к %1$s закончился",
    "The public link of %2$s for %1$s expired" : "Срок действия общедоступной ссылки к %2$s для %1$s закончился",
    "%2$s shared %1$s with you" : "%2$s поделился с вами %1$s",
    "%2$s removed the share for %1$s" : "%2$s удалил общий доступ к %1$s",
    "Shared with %2$s" : "Поделился с %2$s",
    "Shared with %3$s by %2$s" : "Поделился %2$s с %3$s",
    "Removed share for %2$s" : "Удалён общий доступ к %2$s",
    "%2$s removed share for %3$s" : "%2$s удалил общий доступ к %3$s",
    "Shared with group %2$s" : "Поделился с группой %2$s",
    "Shared with group %3$s by %2$s" : "Поделился %2$s с группой %3$s",
    "Removed share of group %2$s" : "Удалён общий доступ к группе %2$s",
    "%2$s removed share of group %3$s" : "%2$s удалил общий доступ к группе %3$s",
    "Shared via link by %2$s" : "Поделился ссылкой %2$s",
    "Shared via public link" : "Поделился открытой ссылкой",
    "%2$s removed public link" : "%2$s удалил общедоступную ссылку",
    "Public link of %2$s expired" : "Срок действия общедоступной ссылки к %2$s закончился",
    "Shared by %2$s" : "Поделился %2$s",
    "Shares" : "События обмена файлами"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
